@@ -46,7 +46,7 @@ raw values read out
 """
 
 
-__version__ = '1.3.2'
+__version__ = '1.3.3'
 
 import serial
 import time
@@ -283,11 +283,12 @@ def cmd_log(args):
     if(not args.override_run):
         if get_mvm_param(ser, "run") == "1":
             set_mvm_param(ser, "run", 0)
-            time.sleep(5)
 
     # Should we configure the ESP32 with settings from a previous logfile?
     if(args.use_cfg is not None):
         set_log_settings(args.use_cfg, verbose)
+        # Wait some time for those settings to come into effect
+        time.sleep(5)
 
     # Run through the dict getting our responses
     settings_resp = get_log_settings()
@@ -415,12 +416,17 @@ def cmd_console_log(args):
     if(not args.override_run):
         if get_mvm_param(ser, "run") == "1":
             set_mvm_param(ser, "run", 0)
-            time.sleep(5)
 
     # Should we configure the ESP32 with settings from a previous logfile?
     if(args.use_cfg is not None):
         set_log_settings(args.use_cfg)
 
+        # Wait a bit and clear out the old settings
+        time_to_poll = time.time()
+        while(time.time() < (time_to_poll + 5.0)):
+            resp = ser.read_until().decode('utf-8').strip()
+            time.sleep(0.01)
+
     # Run through the dict getting our responses
     settings_resp = get_log_settings()
 
